summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorZick Wei <zick.wei@quanta.corp-partner.google.com>2022-01-05 10:39:48 +0800
committerCommit Bot <commit-bot@chromium.org>2022-01-19 04:57:53 +0000
commit845462f05455ccb400f358d5510772b854130bf0 (patch)
tree7ea3867efcb746f2d4b4f1d6f3dee22471dfb6f5
parent00433beb832bf8ae91fb7cc530e34477a5134cf1 (diff)
downloadchrome-ec-845462f05455ccb400f358d5510772b854130bf0.tar.gz
agah: rename draco to agah
BUG=b:210970640 BRANCH=none TEST=make BOARD=agah Signed-off-by: Zick Wei <zick.wei@quanta.corp-partner.google.com> Change-Id: I8556de9a8fc2c827cb136eb90ca09e6df8c6c51a Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/platform/ec/+/3367356 Reviewed-by: caveh jalali <caveh@chromium.org>
-rw-r--r--board/agah/battery.c (renamed from board/draco/battery.c)2
-rw-r--r--board/agah/board.c (renamed from board/draco/board.c)0
-rw-r--r--board/agah/board.h (renamed from board/draco/board.h)4
-rw-r--r--board/agah/build.mk (renamed from board/draco/build.mk)2
-rw-r--r--board/agah/charger_isl9241.c (renamed from board/draco/charger_isl9241.c)0
-rw-r--r--board/agah/ec.tasklist (renamed from board/draco/ec.tasklist)0
-rw-r--r--board/agah/fans.c (renamed from board/draco/fans.c)0
-rw-r--r--board/agah/fw_config.c (renamed from board/draco/fw_config.c)10
-rw-r--r--board/agah/fw_config.h (renamed from board/draco/fw_config.h)14
-rw-r--r--board/agah/gpio.inc (renamed from board/draco/gpio.inc)0
-rw-r--r--board/agah/i2c.c (renamed from board/draco/i2c.c)0
-rw-r--r--board/agah/keyboard.c (renamed from board/draco/keyboard.c)0
-rw-r--r--board/agah/led.c (renamed from board/draco/led.c)2
-rw-r--r--board/agah/pwm.c (renamed from board/draco/pwm.c)0
-rw-r--r--board/agah/sensors.c (renamed from board/draco/sensors.c)0
-rw-r--r--board/agah/usbc_config.c (renamed from board/draco/usbc_config.c)0
-rw-r--r--board/agah/usbc_config.h (renamed from board/draco/usbc_config.h)2
-rw-r--r--board/agah/vif_override.xml (renamed from board/draco/vif_override.xml)0
18 files changed, 18 insertions, 18 deletions
diff --git a/board/draco/battery.c b/board/agah/battery.c
index fbada9a9f1..b9adcb4db9 100644
--- a/board/draco/battery.c
+++ b/board/agah/battery.c
@@ -11,7 +11,7 @@
#include "compile_time_macros.h"
#include "gpio.h"
/*
- * Battery info for all Draco battery types. Note that the fields
+ * Battery info for all Agah battery types. Note that the fields
* start_charging_min/max and charging_min/max are not used for the charger.
* The effective temperature limits are given by discharging_min/max_c.
*
diff --git a/board/draco/board.c b/board/agah/board.c
index 261aebf80c..261aebf80c 100644
--- a/board/draco/board.c
+++ b/board/agah/board.c
diff --git a/board/draco/board.h b/board/agah/board.h
index 58abc1e694..1dd4a23b9f 100644
--- a/board/draco/board.h
+++ b/board/agah/board.h
@@ -3,7 +3,7 @@
* found in the LICENSE file.
*/
-/* Draco board configuration */
+/* Agah board configuration */
#ifndef __CROS_EC_BOARD_H
#define __CROS_EC_BOARD_H
@@ -11,7 +11,7 @@
#include "compile_time_macros.h"
/*
- * Early draco boards are not set up for vivaldi
+ * Early agah boards are not set up for vivaldi
*/
#undef CONFIG_KEYBOARD_VIVALDI
diff --git a/board/draco/build.mk b/board/agah/build.mk
index 61485378cd..fbdd503bc4 100644
--- a/board/draco/build.mk
+++ b/board/agah/build.mk
@@ -3,7 +3,7 @@
# Use of this source code is governed by a BSD-style license that can be
# found in the LICENSE file.
#
-# Draco board specific files build
+# Agah board specific files build
#
CHIP:=npcx
diff --git a/board/draco/charger_isl9241.c b/board/agah/charger_isl9241.c
index 85e0de90fe..85e0de90fe 100644
--- a/board/draco/charger_isl9241.c
+++ b/board/agah/charger_isl9241.c
diff --git a/board/draco/ec.tasklist b/board/agah/ec.tasklist
index d866e2349e..d866e2349e 100644
--- a/board/draco/ec.tasklist
+++ b/board/agah/ec.tasklist
diff --git a/board/draco/fans.c b/board/agah/fans.c
index ca816af8ab..ca816af8ab 100644
--- a/board/draco/fans.c
+++ b/board/agah/fans.c
diff --git a/board/draco/gpio.inc b/board/agah/gpio.inc
index 715bff4f67..715bff4f67 100644
--- a/board/draco/gpio.inc
+++ b/board/agah/gpio.inc
diff --git a/board/draco/i2c.c b/board/agah/i2c.c
index 3db2e0c17b..3db2e0c17b 100644
--- a/board/draco/i2c.c
+++ b/board/agah/i2c.c
diff --git a/board/draco/keyboard.c b/board/agah/keyboard.c
index a9f033130d..a9f033130d 100644
--- a/board/draco/keyboard.c
+++ b/board/agah/keyboard.c
diff --git a/board/draco/led.c b/board/agah/led.c
index 74764a8ef4..df5ac10f06 100644
--- a/board/draco/led.c
+++ b/board/agah/led.c
@@ -3,7 +3,7 @@
* found in the LICENSE file.
*/
-/* Draco specific PWM LED settings: there are 2 LEDs on each side of the board,
+/* Agah specific PWM LED settings: there are 2 LEDs on each side of the board,
* each one can be controlled separately. The LED colors are white or amber,
* and the default behavior is tied to the charging process: both sides are
* amber while charging the battery and white when the battery is charged.
diff --git a/board/draco/pwm.c b/board/agah/pwm.c
index 2203f14c8d..2203f14c8d 100644
--- a/board/draco/pwm.c
+++ b/board/agah/pwm.c
diff --git a/board/draco/sensors.c b/board/agah/sensors.c
index b68984c95c..b68984c95c 100644
--- a/board/draco/sensors.c
+++ b/board/agah/sensors.c
diff --git a/board/draco/usbc_config.c b/board/agah/usbc_config.c
index 1475e1f536..1475e1f536 100644
--- a/board/draco/usbc_config.c
+++ b/board/agah/usbc_config.c
diff --git a/board/draco/usbc_config.h b/board/agah/usbc_config.h
index 512580d704..d407a7ae8d 100644
--- a/board/draco/usbc_config.h
+++ b/board/agah/usbc_config.h
@@ -3,7 +3,7 @@
* found in the LICENSE file.
*/
-/* Draco board-specific USB-C configuration */
+/* Agah board-specific USB-C configuration */
#ifndef __CROS_EC_USBC_CONFIG_H
#define __CROS_EC_USBC_CONFIG_H
diff --git a/board/draco/vif_override.xml b/board/agah/vif_override.xml
index 32736caf64..32736caf64 100644
--- a/board/draco/vif_override.xml
+++ b/board/agah/vif_override.xml
diff --git a/board/draco/fw_config.c b/board/agah/fw_config.c
index 7dd00954e8..5e71816e35 100644
--- a/board/draco/fw_config.c
+++ b/board/agah/fw_config.c
@@ -12,20 +12,20 @@
#define CPRINTS(format, args...) cprints(CC_CHIPSET, format, ## args)
-static union draco_cbi_fw_config fw_config;
+static union agah_cbi_fw_config fw_config;
BUILD_ASSERT(sizeof(fw_config) == sizeof(uint32_t));
/*
* FW_CONFIG defaults for draco if the CBI.FW_CONFIG data is not
* initialized.
*/
-static const union draco_cbi_fw_config fw_config_defaults = {
+static const union agah_cbi_fw_config fw_config_defaults = {
.usb_db = DB_USB3_PS8815,
.kb_bl = KEYBOARD_BACKLIGHT_ENABLED,
};
/****************************************************************************
- * Draco FW_CONFIG access
+ * Agah FW_CONFIG access
*/
void board_init_fw_config(void)
{
@@ -35,7 +35,7 @@ void board_init_fw_config(void)
}
}
-union draco_cbi_fw_config get_fw_config(void)
+union agah_cbi_fw_config get_fw_config(void)
{
return fw_config;
}
@@ -12,20 +12,20 @@
BUILD_ASSERT(sizeof(fw_config) == sizeof(uint32_t));
/*
- * FW_CONFIG defaults for draco if the CBI.FW_CONFIG data is not
+ * FW_CONFIG defaults for agah if the CBI.FW_CONFIG data is not
* initialized.
*/
diff --git a/board/draco/fw_config.h b/board/agah/fw_config.h
index eea18a6e14..8737b283f7 100644
--- a/board/draco/fw_config.h
+++ b/board/agah/fw_config.h
@@ -3,15 +3,15 @@
* found in the LICENSE file.
*/
-#ifndef __BOARD_DRACO_FW_CONFIG_H_
-#define __BOARD_DRACO_FW_CONFIG_H_
+#ifndef __BOARD_AGAH_FW_CONFIG_H_
+#define __BOARD_AGAH_FW_CONFIG_H_
#include <stdint.h>
/****************************************************************************
* CBI FW_CONFIG layout for Draco board.
*
* Source of truth is the project/brya/draco/config.star configuration file.
*/
enum ec_cfg_usb_db_type {
@@ -25,7 +25,7 @@ enum ec_cfg_keyboard_backlight_type {
KEYBOARD_BACKLIGHT_ENABLED = 1
};
-union draco_cbi_fw_config {
+union agah_cbi_fw_config {
struct {
enum ec_cfg_usb_db_type usb_db : 4;
uint32_t sd_db : 2;
@@ -42,7 +42,7 @@ union draco_cbi_fw_config {
*
* @return the FW_CONFIG for the board.
*/
-union draco_cbi_fw_config get_fw_config(void);
+union agah_cbi_fw_config get_fw_config(void);
/**
* Get the USB daughter board type from FW_CONFIG.
@@ -51,4 +51,4 @@ union draco_cbi_fw_config get_fw_config(void);
*/
enum ec_cfg_usb_db_type ec_cfg_usb_db_type(void);
-#endif /* __BOARD_DRACO_FW_CONFIG_H_ */
+#endif /* __BOARD_AGAH_FW_CONFIG_H_ */
@@ -3,15 +3,15 @@
#include <stdint.h>
/****************************************************************************
- * CBI FW_CONFIG layout for Draco board.
+ * CBI FW_CONFIG layout for Agah board.
*
@@ -3,15 +3,15 @@
*
- * Source of truth is the project/brya/draco/config.star configuration file.
+ * Source of truth is the project/brya/agah/config.star configuration file.
*/
enum ec_cfg_usb_db_type {